# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import tech_inspection_service_client
from tech_inspection_service_client.api.operators_api import OperatorsApi  # noqa: E501
from tech_inspection_service_client.rest import ApiException


class TestOperatorsApi(unittest.TestCase):
    """OperatorsApi unit test stubs"""

    def setUp(self):
        self.api = tech_inspection_service_client.api.operators_api.OperatorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_operator(self):
        """Test case for add_operator

        Add new operator  # noqa: E501
        """
        pass

    def test_get_operator_by_id(self):
        """Test case for get_operator_by_id

        Get operator by operatorId  # noqa: E501
        """
        pass

    def test_remove_operator(self):
        """Test case for remove_operator

        Remove operator  # noqa: E501
        """
        pass

    def test_update_operator(self):
        """Test case for update_operator

        Update operator info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
