# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tech_inspection_service_client
from tech_inspection_service_client.models.error import Error  # noqa: E501
from tech_inspection_service_client.rest import ApiException

class TestError(unittest.TestCase):
    """Error unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Error
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tech_inspection_service_client.models.error.Error()  # noqa: E501
        if include_optional :
            return Error(
                code = '0', 
                target = '0', 
                message = '0', 
                details = [
                    tech_inspection_service_client.models.error.Error(
                        code = '0', 
                        target = '0', 
                        message = '0', 
                        details = [
                            tech_inspection_service_client.models.error.Error(
                                code = '0', 
                                target = '0', 
                                message = '0', )
                            ], )
                    ]
            )
        else :
            return Error(
        )

    def testError(self):
        """Test Error"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
