# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import tech_inspection_service_client
from tech_inspection_service_client.api.points_api import PointsApi  # noqa: E501
from tech_inspection_service_client.rest import ApiException


class TestPointsApi(unittest.TestCase):
    """PointsApi unit test stubs"""

    def setUp(self):
        self.api = tech_inspection_service_client.api.points_api.PointsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_point(self):
        """Test case for add_point

        Add new point to operator  # noqa: E501
        """
        pass

    def test_get_point_by_id(self):
        """Test case for get_point_by_id

        Get point by pointId  # noqa: E501
        """
        pass

    def test_get_points_by_coordinates(self):
        """Test case for get_points_by_coordinates

        Get points by location route  # noqa: E501
        """
        pass

    def test_get_points_by_location_route(self):
        """Test case for get_points_by_location_route

        Get points by location route  # noqa: E501
        """
        pass

    def test_remove_point(self):
        """Test case for remove_point

        Remove point  # noqa: E501
        """
        pass

    def test_update_point(self):
        """Test case for update_point

        Update point info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
