# coding: utf-8

"""
    TechInspection 1.0

    Сервис получения информации об операторах и точках тех обслуживания  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tech_inspection_service_client
from tech_inspection_service_client.models.tech_inspection_operator_query import TechInspectionOperatorQuery  # noqa: E501
from tech_inspection_service_client.rest import ApiException

class TestTechInspectionOperatorQuery(unittest.TestCase):
    """TechInspectionOperatorQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TechInspectionOperatorQuery
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tech_inspection_service_client.models.tech_inspection_operator_query.TechInspectionOperatorQuery()  # noqa: E501
        if include_optional :
            return TechInspectionOperatorQuery(
                operator_id = 56, 
                name = '0', 
                link = '0', 
                status = 'paused', 
                director_initials = '0', 
                ogrn = '0', 
                org_form = '0', 
                address = '0', 
                address_latitude = 1.337, 
                address_longitude = 1.337, 
                address_route = '0', 
                phone_numbers = [
                    '0'
                    ], 
                emails = [
                    '0'
                    ], 
                tech_inspection_points = [
                    tech_inspection_service_client.models.tech_inspection_point_query.TechInspectionPointQuery(
                        point_id = 56, 
                        operator_id = 56, 
                        name = '0', 
                        status = 'paused', 
                        owner = '0', 
                        address = '0', 
                        address_latitude = 1.337, 
                        address_longitude = 1.337, 
                        address_route = '0', 
                        phone_numbers = [
                            '0'
                            ], 
                        emails = [
                            '0'
                            ], )
                    ]
            )
        else :
            return TechInspectionOperatorQuery(
        )

    def testTechInspectionOperatorQuery(self):
        """Test TechInspectionOperatorQuery"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
